@@ -1,11 +1,11 @@
 package SPOPS::DBI::Oracle;
 
-# $Id: Oracle.pm,v 3.1 2002/09/03 11:43:22 lachoy Exp $
+# $Id: Oracle.pm,v 3.2 2003/01/02 06:00:24 lachoy Exp $
 
 use strict;
 use SPOPS::Utility;
 
-$SPOPS::DBI::Oracle::VERSION  = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::DBI::Oracle::VERSION  = sprintf("%d.%02d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/);
 
 sub sql_quote {
     my ( $class, $value, $type, $db ) = @_;
@@ -112,4 +112,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters  <chris@cwinters.com>
+Chris Winters  E<lt>chris@cwinters.comE<gt>
