@@ -1,12 +1,12 @@
 package SPOPS::Tool::ReadOnly;
 
-# $Id: ReadOnly.pm,v 3.0 2002/08/28 01:16:31 lachoy Exp $
+# $Id: ReadOnly.pm,v 3.1 2003/01/02 06:00:21 lachoy Exp $
 
 use strict;
 use SPOPS               qw( _w DEBUG );
 use SPOPS::ClassFactory qw( OK );
 
-$SPOPS::Tool::ReadOnly::VERSION = sprintf("%d.%02d", q$Revision: 3.0 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Tool::ReadOnly::VERSION = sprintf("%d.%02d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/);
 
 sub behavior_factory {
     my ( $class ) = @_;
@@ -99,4 +99,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters <chris@cwinters.com>
+Chris Winters E<lt>chris@cwinters.comE<gt>
